@@ -343,11 +343,19 @@ class DreamBoothRunner():
         else:
             self.auth_token = getpass.getpass(prompt='HuggingFace access token:')
 
+
+        print('Starting Accelerator')
+        self.accelerator = Accelerator(gradient_accumulation_steps=1,
+            mixed_precision="fp16" if torch.cuda.is_available() else "no", #["no", "fp16", "bf16"]
+            log_with="tensorboard",
+            logging_dir='logs')
+
+
         # Handle the huggingface repository creation
         if self.accelerator.is_main_process:
             if self.config.push_to_hub:
                 if self.config.hub_model_id is None:
-                    repo_name = get_full_repo_name(Path(self.config.output_dir).name, token=self.auth_token)
+                    repo_name = get_full_repo_name(Path(self.config.model_out_dir).name, token=self.auth_token)
                 else:
                     repo_name = self.config.hub_model_id
 
@@ -365,11 +373,7 @@ class DreamBoothRunner():
                 os.makedirs(self.config.model_out_dir, exist_ok=True)
 
 
-        print('Starting Accelerator')
-        self.accelerator = Accelerator(gradient_accumulation_steps=1,
-            mixed_precision="fp16" if torch.cuda.is_available() else "no", #["no", "fp16", "bf16"]
-            log_with="tensorboard",
-            logging_dir='logs')
+
 
         self.tokenizer = CLIPTokenizer.from_pretrained(
             self.config.model_id,
